@@ -7,6 +7,9 @@ extern "C"
 {
 #endif
 
+// forward declaration. This is in <netdnet/dn.h>.
+struct sockaddr_dn;
+
 struct	nodeent	{
 	char	*n_name;		/* name of node */
 	unsigned short n_addrtype;	/* node address type */
@@ -28,7 +31,7 @@ extern  struct  nodeent  *getnodebyaddr(const char *addr, int len, int type);
 extern  struct  nodeent  *getnodebyname(const char *name);
 
 extern  int               dnet_setobjhinum_handling(int handling, int min);
-extern  int               getobjectbyname(char * name);
+extern  int               getobjectbyname(const char * name);
 extern  int               getobjectbynumber(int number, char * name, size_t name_len);
 extern  int               dnet_checkobjectnumber(int num);
 
